/* Application Explorer - a general-purpose application cataloger/indexer
 * Copyright (C) 2006  Aliasgar Lokhandwala <d7@freepgs.com> 
 * http://appexp.sourceforge.net/
 *
 * AboutDialog.java: Shows the about information dialog of the app.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the 
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package app.appexplorer.ui;

import java.awt.Font;
import java.awt.Frame;
import java.awt.GridLayout;
import java.io.IOException;

import javax.swing.BorderFactory;
import javax.swing.JDialog;
import javax.swing.JEditorPane;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.border.BevelBorder;

import app.appexplorer.util.GlobalUtils;

/**
 * Shows the about information dialog of the app.
 * 
 * @version 2
 * @author ali
 */
public class AboutDialog extends JDialog {
    /**
     * Constructs a modal About dialog attached to the supplied owner and
     * displays it instantly.
     * 
     * @param owner -
     *            The owner Frame window for this dialog. Should not be null.
     */
    AboutDialog(Frame owner) {
        super(owner);

        //set location and size
        setLocation(owner.getLocation().x + 30, owner.getLocation().y + 50);
        setSize(650, 370);

        //we are modal
        setModal(true);

        //Title
        setTitle("About Application Explorer");

        //Layout components in this dialog
        boolean err = false;
        JEditorPane ltPane = new JEditorPane();
        ltPane.setEditable(false);
        ltPane.setBorder(BorderFactory.createBevelBorder(BevelBorder.RAISED));
        //try to load the "about" html file
        try {
            ltPane.setPage(ClassLoader.getSystemResource("htm/about.html"));
        } catch (IOException e) {
            //log this
            //dont show the HTML pane
            err = true;
        }

        if (!err) {
            setLayout(new GridLayout(1, 2));
        } else {
            //there will be no left side HTML pane
            setLayout(new GridLayout(1, 1));
        }

        JPanel rtPanel = new JPanel(new GridLayout(2, 1));

        if (!err)
            add(new JScrollPane(ltPane));

        add(rtPanel);

        JPanel ltTopPanel = new JPanel(new GridLayout(7, 1));
        JPanel ltBottomPanel = new JPanel(new GridLayout(1, 1));
        rtPanel.add(ltTopPanel);
        rtPanel.add(ltBottomPanel);

        //used later for displaying system info.
        Runtime rt = Runtime.getRuntime();

        //add right side labels - license/os/memory etc
        JTextArea licenceBx = new JTextArea();
        licenceBx.setEditable(false);
        licenceBx.setLineWrap(true);
        licenceBx
                .setText("This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.\n\nThis program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License along with this program; if not, write to the\nFree Software Foundation, Inc., Temple Place - Suite 330,Boston, MA 02111-1307, USA.");
        licenceBx.setFont(new Font("SansSerif", Font.PLAIN, 10));
        licenceBx.setToolTipText("License Information");
        ltBottomPanel.add(new JScrollPane(licenceBx));

        
        ltTopPanel.add(new JLabel());

        ltTopPanel.add(new JLabel("OS: " + System.getProperty("os.name")
                + ", ver: " + System.getProperty("os.version") + ", "
                + System.getProperty("os.arch"), JLabel.CENTER));

        ltTopPanel
                .add(new JLabel("JRE: " + System.getProperty("java.vendor")
                        + ", ver: " + System.getProperty("java.version"),
                        JLabel.CENTER));

        ltTopPanel.add(new JLabel("Memory (free/total/max): "
                + GlobalUtils.toKBytes(rt.freeMemory()) + "K/"
                + GlobalUtils.toKBytes(rt.totalMemory()) + "K/"
                + GlobalUtils.toKBytes(rt.maxMemory()) + "K", JLabel.CENTER));

        ltTopPanel.add(new JLabel("No of Processors : "
                + rt.availableProcessors(), JLabel.CENTER));

        //Finally, show the dialog.
        setVisible(true);
    }
}